import { TspClient } from 'tsp-typescript-client/lib/protocol/tsp-client';
import { OutputStyleModel, OutputElementStyle } from 'tsp-typescript-client/lib/models/styles';
export declare class StyleProvider {
    private tspClient;
    private traceId;
    private outputId;
    private tmpStyleObject;
    private styleModel;
    constructor(outputId: string, traceId: string, tspClient: TspClient);
    /**
     * Get the style model for a specific output
     * @param forceUpdate Force the update of the current cached style model from the server
     */
    getStyleModel(forceUpdate?: boolean): Promise<OutputStyleModel | undefined>;
    getStylesTmp(_forceUpdate?: boolean): {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Get the style property value for the specified element style. The style
     * hierarchy is traversed until a value is found.
     *
     * @param elementStyle
     *            the style
     * @param property
     *            the style property
     * @return the style property value, or undefined
     */
    getStyle(elementStyle: OutputElementStyle, property: string): any | undefined;
    /**
     * Get the style property number value for the specified element style. The
     * style hierarchy is traversed until a number value is found, and the
     * returned number value will be multiplied by the first
     * StyleProperties.FACTOR suffixed modifier style that was found
     * along the way, if any.
     *
     * @param elementStyle
     *            the style
     * @param property
     *            the style property
     * @return the style property number value, or undefined
     */
    getNumberStyle(elementStyle: OutputElementStyle, property: string): number | undefined;
    /**
     * Get the style property color value for the specified element style. The
     * style hierarchy is traversed until a color and opacity value is found,
     * and the returned color value will be blended with the first
     * StyleProperties.BLEND suffixed modifier style that was found
     * along the way, if any.
     *
     * @param elementStyle
     *            the style
     * @param property
     *            the style property
     * @return the style property color value, or undefined
     */
    getColorStyle(elementStyle: OutputElementStyle, property: string): {
        color: number;
        alpha: number;
    } | undefined;
    private popNextStyle;
    private blend;
    private blendComponent;
    private rgbStringToColor;
    private rgbaStringToColor;
    private rgbaToColor;
}
//# sourceMappingURL=style-provider.d.ts.map