/***************************************************************************************
 * Copyright (c) 2023 BlackBerry Limited and contributors.
 *
 * Licensed under the MIT license. See LICENSE file in the project root for details.
 ***************************************************************************************/
import React from 'react';
import { AbstractOutputProps } from './abstract-output-component';
export declare enum OptionType {
    DEFAULT = 0,
    CHECKBOX = 1
}
export interface OptionState {
    type: OptionType;
    label: string;
    condition?: () => boolean;
    onClick?: (arg?: unknown) => void;
    arg?: () => unknown;
    subSection?: DropDownSubSection;
}
export interface DropDownSubSection {
    options: OptionState[];
    condition: () => boolean;
    height?: number;
}
declare type OptionProps = AbstractOutputProps & OptionState;
declare abstract class AbstractDropDownOption<P extends OptionProps, S extends OptionState> extends React.Component<P, S> {
    constructor(props: P);
}
export declare class DropDownOption extends AbstractDropDownOption<OptionProps, OptionState> {
    constructor(props: OptionProps);
    render(): JSX.Element;
}
export declare type OptionCheckBoxState = OptionState & {
    checked: () => boolean;
};
declare type OptionCheckBoxProps = OptionProps & OptionCheckBoxState;
export declare class DropDownOptionCheckBox extends AbstractDropDownOption<OptionCheckBoxProps, OptionCheckBoxState> {
    constructor(props: OptionCheckBoxProps);
    render(): JSX.Element;
}
declare type DropDownProps = AbstractOutputProps & {
    dropDownOptions: OptionState[];
    dropDownOpen: boolean;
};
export declare class DropDownComponent extends React.Component<DropDownProps> {
    optionsMenuRef: React.RefObject<HTMLDivElement>;
    constructor(props: DropDownProps);
    render(): JSX.Element;
    renderSection(option: OptionState): React.ReactNode;
    renderOption(option: OptionState): React.ReactNode;
}
export {};
//# sourceMappingURL=drop-down-component.d.ts.map