import * as React from 'react';
import { TimelineChart } from 'timeline-chart/lib/time-graph-model';
import { ResponseStatus } from 'tsp-typescript-client/lib/models/response/responses';
import { TimeGraphEntry } from 'tsp-typescript-client/lib/models/timegraph';
import { AbstractOutputProps } from './abstract-output-component';
import { AbstractTreeOutputComponent, AbstractTreeOutputState } from './abstract-tree-output-component';
import ColumnHeader from './utils/filter-tree/column-header';
import { Entry } from 'tsp-typescript-client';
declare type TimegraphOutputProps = AbstractOutputProps & {
    addWidgetResizeHandler: (handler: () => void) => void;
    removeWidgetResizeHandler: (handler: () => void) => void;
};
declare type TimegraphOutputState = AbstractTreeOutputState & {
    timegraphTree: TimeGraphEntry[];
    markerCategoryEntries: Entry[];
    markerLayerData: {
        rows: TimelineChart.TimeGraphRowModel[];
        range: TimelineChart.TimeGraphRange;
        resolution: number;
    } | undefined;
    selectedRow?: number;
    selectedMarkerRow?: number;
    collapsedNodes: number[];
    collapsedMarkerNodes: number[];
    columns: ColumnHeader[];
    dataRows: TimelineChart.TimeGraphRowModel[];
    searchString: string;
};
export declare class TimegraphOutputComponent extends AbstractTreeOutputComponent<TimegraphOutputProps, TimegraphOutputState> {
    private totalHeight;
    private rowController;
    private markerRowController;
    private chartLayer;
    private markersChartLayer;
    private vscrollLayer;
    private chartCursors;
    private markerChartCursors;
    private arrowLayer;
    private rangeEventsLayer;
    private horizontalContainer;
    private timeGraphTreeRef;
    private markerTreeRef;
    private tspDataProvider;
    private styleProvider;
    private styleMap;
    private selectedElement;
    private selectedMarkerCategories;
    private onSelectionChanged;
    private pendingSelection;
    private _debouncedUpdateSearch;
    constructor(props: TimegraphOutputProps);
    synchronizeTreeScroll(): void;
    componentDidMount(): Promise<void>;
    componentWillUnmount(): void;
    protected subscribeToEvents(): void;
    protected unsubscribeToEvents(): void;
    fetchTree(): Promise<ResponseStatus>;
    componentDidUpdate(prevProps: TimegraphOutputProps, prevState: TimegraphOutputState): Promise<void>;
    updateSearchFilter(): Promise<void>;
    private onToggleCollapse;
    private onToggleAnnotationCollapse;
    private onMarkerCategoryRowClose;
    private updateTotalHeight;
    private isVisible;
    private doHandleSelectionChangedSignal;
    /**
     * For each line in the tree (this.state.timegraphTree), parse the metadata and try to find
     * matches with the key / values pairs of the selected event.
     * It counts the amount of metadata matches and returns the TimeGraphEntry with the greatest amount,
     * which is the most likely result.
     *
     * @params payload
     *      Object with information about the selected event.
     * @return
     *      Correspondent TimeGraphEntry from this.state.timegraphTree
     */
    private findElement;
    private getMarkersLayerHeight;
    renderTree(): React.ReactNode;
    renderYAxis(): React.ReactNode;
    renderChart(): React.ReactNode;
    resultsAreEmpty(): boolean;
    private fetchTooltip;
    private filterTooltip;
    private renderTimeGraphContent;
    private onKeyDown;
    private handleSearchChange;
    private clearSearchBox;
    private getMarkersContainer;
    private getChartContainer;
    setFocus(): void;
    protected getVerticalScrollbar(): JSX.Element;
    private onElementSelected;
    private getTimegraphRowIds;
    private fetchTimegraphData;
    private updateMarkersData;
    private getMarkersRowIds;
    private fetchMarkersData;
    private getRowStyle;
    onThemeChange: () => void;
    private getMarkerStateStyle;
    private getStateStyle;
    private getDefaultStateStyle;
    private getAnnotationStyle;
    private expandParents;
    /**
     *  This method is passed down all the way to TableCell component.
     *  It communicates a row-selection with the timeline-chart component.
     *  @param {number} id TreeNode id number
     */
    onRowClick: (id: number) => void;
    onMarkerRowClick: (id: number) => void;
    onSelectionChange: (row: TimelineChart.TimeGraphRowModel) => void;
    onMarkerSelectionChange: (row: TimelineChart.TimeGraphRowModel) => void;
    private selectAndReveal;
}
export {};
//# sourceMappingURL=timegraph-output-component.d.ts.map